@@ -1,7 +1,9 @@
 use strict;
 use warnings;
 package Log::Dispatchouli;
-our $VERSION = '1.100711';
+BEGIN {
+  $Log::Dispatchouli::VERSION = '1.102220';
+}
 # ABSTRACT: a simple wrapper around Log::Dispatch
 
 use Carp ();
@@ -11,6 +13,8 @@ use Scalar::Util qw(blessed weaken);
 use String::Flogger;
 use Try::Tiny 0.04;
 
+our @CARP_NOT = qw(Log::Dispatchouli::Proxy);
+
 
 sub new {
   my ($class, $arg) = @_;
@@ -18,6 +22,14 @@ sub new {
   my $ident = $arg->{ident}
     or Carp::croak "no ident specified when using $class";
 
+  my %quiet_fatal;
+  for ('quiet_fatal') {
+    %quiet_fatal = map {; $_ => 1 } grep { defined }
+      exists $arg->{$_}
+        ? _ARRAY0($arg->{$_}) ? @{ $arg->{$_} } : $arg->{$_}
+        : ('stderr');
+  };
+
   my $pid_prefix = exists $arg->{log_pid} ? $arg->{log_pid} : 1;
 
   my $self = bless {} => $class;
@@ -95,7 +107,8 @@ sub new {
         name      => "std$dest",
         min_level => 'debug',
         stderr    => ($dest eq 'err' ? 1 : 0),
-        callbacks => sub { my %arg = @_; "$arg{message}\n"; }
+        callbacks => sub { my %arg = @_; "$arg{message}\n"; },
+        ($quiet_fatal{"std$dest"} ? (max_level => 'info') : ()),
       ),
     );
   }
@@ -120,32 +133,35 @@ sub log {
   my $arg = _HASH0($rest[0]) ? shift(@rest) : {};
 
   my $message;
-  try {
-    my @flogged = map {; String::Flogger->flog($_) } @rest;
-    $message    = @flogged > 1 ? $self->_join(\@flogged) : $flogged[0];
 
-    my $prefix  = _ARRAY0($arg->{prefix})
-                ? [ @{ $arg->{prefix} } ]
-                : [ $arg->{prefix} ];
+  if ($arg->{fatal} or ! $self->get_muted) {
+    try {
+      my @flogged = map {; String::Flogger->flog($_) } @rest;
+      $message    = @flogged > 1 ? $self->_join(\@flogged) : $flogged[0];
 
-    for (reverse grep { defined } $self->get_prefix, @$prefix) {
-      if (_CODELIKE( $_ )) {
-        $message = $_->($message);
-      } else {
-        $message =~ s/^/$_/gm;
+      my $prefix  = _ARRAY0($arg->{prefix})
+                  ? [ @{ $arg->{prefix} } ]
+                  : [ $arg->{prefix} ];
+
+      for (reverse grep { defined } $self->get_prefix, @$prefix) {
+        if (_CODELIKE( $_ )) {
+          $message = $_->($message);
+        } else {
+          $message =~ s/^/$_/gm;
+        }
       }
-    }
 
-    $self->dispatcher->log(
-      level   => $arg->{level} || 'info',
-      message => $message,
-    );
-  } catch {
-    $message = '(no message could be logged)' unless defined $message;
-    die $_ if $self->{fail_fatal};
-  };
+      $self->dispatcher->log(
+        level   => $arg->{level} || 'info',
+        message => $message,
+      );
+    } catch {
+      $message = '(no message could be logged)' unless defined $message;
+      die $_ if $self->{fail_fatal};
+    };
+  }
 
-  die $message if $arg->{fatal};
+  Carp::croak $message if $arg->{fatal};
 
   return;
 }
@@ -153,8 +169,9 @@ sub log {
 
 sub log_fatal {
   my ($self, @rest) = @_;
-  my $arg;
-  $arg = _HASH0($rest[0]) ? shift(@rest) : {}; # for future expansion
+
+  my $arg = _HASH0($rest[0]) ? shift(@rest) : {}; # for future expansion
+
   local $arg->{level} = defined $arg->{level} ? $arg->{level} : 'error';
   local $arg->{fatal} = defined $arg->{fatal} ? $arg->{fatal} : 1;
 
@@ -167,8 +184,8 @@ sub log_debug {
 
   return unless $self->is_debug;
 
-  my $arg;
-  $arg = _HASH0($rest[0]) ? shift(@rest) : {}; # for future expansion
+  my $arg = _HASH0($rest[0]) ? shift(@rest) : {}; # for future expansion
+
   local $arg->{level} = defined $arg->{level} ? $arg->{level} : 'debug';
 
   $self->log($arg, @rest);
@@ -185,6 +202,20 @@ sub get_debug { return $_[0]->{debug} }
 
 sub clear_debug { }
 
+sub mute   { $_[0]{muted} = 1 }
+sub unmute { $_[0]{muted} = 0 }
+
+
+sub set_muted {
+  return($_[0]->{muted} = $_[1] ? 1 : 0);
+}
+
+
+sub get_muted { return $_[0]->{muted} }
+
+
+sub clear_muted { }
+
 
 sub get_prefix   { return $_[0]->{prefix}  }
 sub set_prefix   { $_[0]->{prefix} = $_[1] }
@@ -198,6 +229,7 @@ sub new_tester {
 
   return $class->new({
     ident     => "$$:$0",
+    log_pid   => 0,
     %$arg,
     to_stderr => 0,
     to_stdout => 0,
@@ -271,7 +303,7 @@ Log::Dispatchouli - a simple wrapper around Log::Dispatch
 
 =head1 VERSION
 
-version 1.100711
+version 1.102220
 
 =head1 SYNOPSIS
 
@@ -317,16 +349,20 @@ This returns a new logger, a Log::Dispatchouli object.
 
 Valid arguments are:
 
-  ident      - the name of the thing logging (mandatory)
-  to_self    - log to the logger object for testing; default: false
-  to_file    - log to PROGRAM_NAME.YYYYMMDD in the log path; default: false
-  to_stdout  - log to STDOUT; default: false
-  to_stderr  - log to STDERR; default: false
-  facility   - to which syslog facility to send logs; default: none
-  log_pid    - if true, prefix all log entries with the pid; default: true
-  fail_fatal - a boolean; if true, failure to log is fatal; default: true
-  debug      - a boolean; if true, log_debug method is not a no-op
-               defaults to the truth of the DISPATCHOULI_DEBUG env var
+  ident       - the name of the thing logging (mandatory)
+  to_self     - log to the logger object for testing; default: false
+  to_file     - log to PROGRAM_NAME.YYYYMMDD in the log path; default: false
+  to_stdout   - log to STDOUT; default: false
+  to_stderr   - log to STDERR; default: false
+  facility    - to which syslog facility to send logs; default: none
+  log_pid     - if true, prefix all log entries with the pid; default: true
+  fail_fatal  - a boolean; if true, failure to log is fatal; default: true
+  muted       - a boolean; if true, only fatals are logged; default: false
+  debug       - a boolean; if true, log_debug method is not a no-op
+                defaults to the truth of the DISPATCHOULI_DEBUG env var
+  quiet_fatal - 'stderr' or 'stdout' or an arrayref of zero, one, or both
+                fatal log messages will not be logged to these
+                (default: stderr)
 
 The log path is either F</tmp> or the value of the F<DISPATCHOULI_PATH> env var.
 
@@ -381,6 +417,23 @@ C<log_debug>.
 This method does nothing, and is only useful for L<Log::Dispatchouli::Proxy>
 objects.  See L<Methods for Proxy Loggers|/METHODS FOR PROXY LOGGERS>, below.
 
+=head2 set_muted
+
+  $logger->set_muted($bool);
+
+This sets the logger's muted property, which affects the behavior of
+C<log>.
+
+=head2 get_muted
+
+This gets the logger's muted property, which affects the behavior of
+C<log>.
+
+=head2 clear_muted
+
+This method does nothing, and is only useful for L<Log::Dispatchouli::Proxy>
+objects.  See L<Methods for Proxy Loggers|/METHODS FOR PROXY LOGGERS>, below.
+
 =head2 get_prefix
 
   my $prefix = $logger->get_prefix;
@@ -548,7 +601,7 @@ L<String::Flogger>
 
 =head1 AUTHOR
 
-  Ricardo SIGNES <rjbs@cpan.org>
+Ricardo SIGNES <rjbs@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
